<?php
/**
 * Plugin Name: Salesbeat - Интегратор способов доставки
 * Plugin URI: https://salesbeat.pro/integrations/wordpress-woocommerce
 * Description: Плагин позволяет выводить виджет расчета доставок на странице оформления заказа.
 * Version: 1.1.1
 * Author: Salesbeat
 * Author URI: https://salesbeat.pro
 */

defined('ABSPATH') || exit;

$actPlugins = apply_filters('active_plugins', get_option('active_plugins'));
if (!in_array('woocommerce/woocommerce.php', $actPlugins))
    exit;

if (!defined('SALESBEAT_PLUGIN_FILE'))
    define('SALESBEAT_PLUGIN_FILE', __FILE__);

define('SALESBEAT_PLUGIN_NAME', basename(__DIR__));

// Подключаем lib классы Salesbeat
include __DIR__ . '/lib/api.class.php';
include __DIR__ . '/lib/http.class.php';
include __DIR__ . '/lib/storage.class.php';
include __DIR__ . '/lib/tools.class.php';

// Взаимодействие с плагином
include __DIR__ . '/includes/plugin.class.php';
register_activation_hook(__FILE__, ['Salesbeat\Inc\Plugin', 'activate']); // При активации плагина
register_deactivation_hook(__FILE__, ['Salesbeat\Inc\Plugin', 'deactivate']); // При деактивации плагина
register_uninstall_hook(__FILE__, ['Salesbeat\Inc\Plugin', 'uninstall']); // При удалении плагина
add_filter('plugin_action_links', ['Salesbeat\Inc\Plugin', 'settingsLink'], 10, 4);

// Inc
include __DIR__ . '/includes/adminOrdersTable.class.php';
include __DIR__ . '/includes/adminOrders.class.php';
include __DIR__ . '/includes/adminSettings.class.php';
include __DIR__ . '/includes/adminMenu.class.php';
include __DIR__ . '/includes/ajax.class.php';
include __DIR__ . '/includes/adminOrderShipping.class.php';

function shippingMethodInit()
{
    include __DIR__ . '/includes/shipping.class.php';

    add_filter('woocommerce_shipping_methods', ['Salesbeat\Inc\Shipping', 'shippingMethod']);
    add_action('woocommerce_after_shipping_rate', ['Salesbeat\Inc\Shipping', 'afterShippingRate']);
    add_filter('woocommerce_available_payment_gateways', ['Salesbeat\Inc\Shipping', 'paymentsOnShipping']);
}

add_action('woocommerce_shipping_init', 'shippingMethodInit');

// Валидация доставки
function validationShipping()
{
    $chosenShipping = WC()->session->get('chosen_shipping_methods');
    $chosenList = explode(':', $chosenShipping[0]);

    $storage = \Salesbeat\Lib\Storage::main()->getByID('public');
    if (!$storage && $chosenList[0] == 'salesbeat')
        wc_add_notice(__('Пожалуйста, уточните способ доставки'), 'error');
}

add_action('woocommerce_checkout_process', 'validationShipping');

// Добавляем контейнер Salesbeat в информациюю о заказе
add_action('add_meta_boxes', [new Salesbeat\Inc\AdminOrderShipping, 'addMetaBoxes']);

// Добавляем скрипты и стили в паблик
function outputHead()
{
    wp_enqueue_style('sbPublicShipping', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/css/sbPublicShipping.css'), [], '1.0.0');
    wp_enqueue_style('sbPublicProduct', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/css/sbPublicProduct.css'), [], '1.0.0');

    wp_enqueue_script('sbWidget', '//app.salesbeat.pro/static/widget/js/widget.js');
    wp_enqueue_script('sbCartWidget', '//app.salesbeat.pro/static/widget/js/cart_widget.js');
    wp_enqueue_script('sbTools', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/js/sbTools.js'));
    wp_enqueue_script('sbPublicShipping', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/js/sbPublicShipping.js'));

    wp_localize_script('sbTools', 'sbAjaxOption', ['url' => admin_url('admin-ajax.php')]);
}

add_action('wp_enqueue_scripts', 'outputHead');

// Добавляем скрипты и стили в админку
function outputHeadAdmin()
{
    wp_enqueue_style('sbAdminSettings', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/css/sbAdminSettings.css'), [], '1.0.0');
    wp_enqueue_style('sbAdminOrders', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/css/sbAdminOrders.css'), [], '1.0.0');

    wp_enqueue_script('sbTools', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/js/sbTools.js'), [], '1.0.0');
    wp_enqueue_script('sbAdminSettings', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/js/sbAdminSettings.js'), [], '1.0.0');
    wp_enqueue_script('sbAdminOrders', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/js/sbAdminOrders.js'), [], '1.0.0');
    wp_enqueue_script('sbAdminSettings', plugins_url(SALESBEAT_PLUGIN_NAME . '/assets/js/sbAdminSettings.js'), [], '1.0.0');

    wp_localize_script('sbTools', 'sbAjaxOption', ['url' => admin_url('admin-ajax.php')]);
}

add_action('admin_enqueue_scripts', 'outputHeadAdmin');

// Подключаем Ajax обработчики
add_action('wp_ajax_nopriv_sbCallBack', [new Salesbeat\Inc\Ajax, 'callBack']);
add_action('wp_ajax_sbCallBack', [new Salesbeat\Inc\Ajax, 'callBack']);
add_action('wp_ajax_sbSendOrder', [new Salesbeat\Inc\Ajax, 'sendOrder']);
add_action('wp_ajax_sbSyncPaySystem', [new Salesbeat\Inc\Ajax, 'syncPaySystem']);

// Скрываем свойства в заказе
function hiddenCheckoutFields($fields)
{
    $fieldsHidden = get_option('salesbeat_property_checkout_hidden');
    if (!$fieldsHidden || !is_array($fieldsHidden)) return $fields;

    foreach ($fieldsHidden as $fieldHidden) {
        $fields['billing'][$fieldHidden]['required'] = false;
        unset($fields['billing'][$fieldHidden]);

        if ($fieldHidden = 'billing_country')
            unset($fields['shipping']['shipping_country']);
    }

    return $fields;
}

add_filter('woocommerce_checkout_fields', 'hiddenCheckoutFields');

// Применяем мета данные к доставки к заказу и удаляем транзит
function checkoutUpdateOrderMeta($orderId)
{
    $storage = \Salesbeat\Lib\Storage::main()->getByID('public');
    \Salesbeat\Lib\Storage::main()->deleteById('public');

    if (empty($storage)) return false;

    $order = wc_get_order($orderId);
    $shippingList = $order->get_shipping_methods();
    $shipping = $shippingList[key($shippingList)] ? $shippingList[key($shippingList)]->get_data() : [];
    $deliveryId = $shipping['method_id'] . ':' . $shipping['instance_id'];

    if ($storage['delivery_id'] === $deliveryId)
        update_post_meta($orderId, '_shipping_salesbeat', $storage);

    return true;
}

add_action('woocommerce_checkout_update_order_meta', 'checkoutUpdateOrderMeta');

// Добавление информации о доставке
function getDeliveryInfo($product, $mainDivId = 'salesbeat-deliveries')
{
    $fromWeightUnit = get_option('woocommerce_weight_unit');
    $fromDimensionUnit = get_option('woocommerce_dimension_unit');

    $result = [
        'token' => get_option('salesbeat_system_api_token'),
        'price_to_pay' => $product->get_price(),
        'price_insurance' => $product->get_price(),
        'weight' => ceil(wc_get_weight($product->get_weight(), 'g', $fromWeightUnit)),
        'x' => ceil(wc_get_dimension($product->get_length(), 'sm', $fromDimensionUnit)),
        'y' => ceil(wc_get_dimension($product->get_width(), 'sm', $fromDimensionUnit)),
        'z' => ceil(wc_get_dimension($product->get_height(), 'sm', $fromDimensionUnit)),
        'quantity' => 1,
        'city_by' => 'ip',
        'params_by' => 'params',
        'main_div_id' => $mainDivId,
    ];

    ob_start();
    include 'includes/views/product.php';
    echo ob_get_clean();
}

add_action('salesbeat_product_widget', 'getDeliveryInfo', 10, 2);

// Добавляем вкладку с доставкой
function addProductTabDelivery($tabs)
{
    $tabs['sb_delivery'] = [
        'title' => __('Доставка', 'salesbeat'),
        'priority' => 100,
        'callback' => function () {
            ob_start();
            include 'includes/views/productTabDelivery.php';
            echo ob_get_clean();
        }
    ];

    return $tabs;
}

add_filter('woocommerce_product_tabs', 'addProductTabDelivery', 99);